@@ -37,6 +37,12 @@ def create_update_geometry_command(cli: Group) -> Command:
         type=int,
         help="The factor by which to increase point density within the polygon.",
     )
+    @click.option(
+        "-i",
+        "--densification-distance",
+        type=float,
+        help="The distance interval at which to increase point density within the polygon",
+    )
     @click.option(
         "-s",
         "--simplify-tolerance",
@@ -60,28 +66,40 @@ def create_update_geometry_command(cli: Group) -> Command:
         default="1",
         show_default=True,
     )
+    @click.option(
+        "-e",
+        "--skip-errors",
+        help="Do not raise errors for missing hrefs or footprint calculation failures",
+        type=bool,
+        default=True,
+        show_default=True,
+    )
     def update_geometry_command_raster_command(
         item_path: str,
         asset_names: List[str],
         precision: int,
         densification_factor: Optional[int],
+        densification_distance: Optional[float],
         simplify_tolerance: Optional[float],
         no_data: Optional[int],
         bands: str,
+        skip_errors: bool,
     ) -> None:
         item = Item.from_file(item_path)
         if bands.lower() == "all":
             band_list = []
         else:
             band_list = list(int(band) for band in bands.split(","))
-        success = raster_footprint.update_geometry_from_asset_footprint(
+        success = raster_footprint.RasterFootprint.update_geometry_from_asset_footprint(
             item,
             asset_names=asset_names,
             precision=precision,
             densification_factor=densification_factor,
+            densification_distance=densification_distance,
             simplify_tolerance=simplify_tolerance,
             no_data=no_data,
             bands=band_list,
+            skip_errors=skip_errors,
         )
         if success:
             item.save_object()
