@@ -1,9 +1,11 @@
 """Input/output utility functions and definitions."""
 
-from typing import Callable, Optional
+import os
+from typing import Any, Callable, Optional
 
 import fsspec
-from pystac.stac_io import DefaultStacIO, StacIO
+from pystac.link import HREF
+from pystac.stac_io import StacIO
 
 from stactools.core import utils
 
@@ -14,7 +16,11 @@ Used for reading, e.g. appending an Azure SAS Token or translating to a signed U
 """
 
 
-def read_text(href: str, read_href_modifier: Optional[ReadHrefModifier] = None) -> str:
+def read_text(
+    href: str,
+    read_href_modifier: Optional[ReadHrefModifier] = None,
+    **kwargs: Any,
+) -> str:
     """Reads a string from an href.
 
     If ``read_href_modifier`` is provided, then ``href`` will be passed through
@@ -26,32 +32,44 @@ def read_text(href: str, read_href_modifier: Optional[ReadHrefModifier] = None)
         read_href_modifier (ReadHrefModifier, optional):
             A function to modify
             the provided href. Defaults to None.
+        **kwargs :
+            Arbitrary keyword arguments that may be utilized by the concrete
+            implementation.
 
     Returns:
         str: The text as read from the href.
     """
     if read_href_modifier is None:
-        return StacIO.default().read_text(href)
+        return StacIO.default().read_text(href, **kwargs)
     else:
-        return StacIO.default().read_text(read_href_modifier(href))
+        return StacIO.default().read_text(read_href_modifier(href), **kwargs)
 
 
-class FsspecStacIO(DefaultStacIO):
+class FsspecStacIO(StacIO):
     """A subclass of :py:class:`pystac.DefaultStacIO` that uses `fsspec
     <https://filesystem-spec.readthedocs.io/en/latest/>`_ for reads and writes.
     """
 
-    def read_text_from_href(self, href: str) -> str:
+    def read_text(self, source: HREF, *args: Any, **kwargs: Any) -> str:
+        """A concrete implementation of :meth:`StacIO.read_text
+        <pystac.StacIO.read_text>`. Converts the ``source`` argument to a string (if it
+        is not already) and delegates to :meth:`FsspecStacIO.read_text_from_href` for
+        opening and reading the file."""
+        href = str(os.fspath(source))
+        return self.read_text_from_href(href, **kwargs)
+
+    def read_text_from_href(self, href: str, **kwargs: Any) -> str:
         """Reads a file as a utf-8 string using `fsspec
         <https://filesystem-spec.readthedocs.io/en/latest/>`_
 
         Args:
             href (str): The href to read.
+            **kwargs: Additional keyword arguments to be passed to fsspec.open.
 
         Returns:
             str: The read text, decoded as utf-8 if necessary.
         """
-        with fsspec.open(href, "r") as f:
+        with fsspec.open(href, "r", **kwargs) as f:
             s = f.read()
             if isinstance(s, str):
                 return s
@@ -60,6 +78,14 @@ class FsspecStacIO(DefaultStacIO):
             else:
                 raise ValueError(f"Unable to decode data loaded from HREF: {href}")
 
+    def write_text(self, dest: HREF, txt: str, *args: Any, **kwargs: Any) -> None:
+        """A concrete implementation of :meth:`StacIO.write_text
+        <pystac.StacIO.write_text>`. Converts the ``dest`` argument to a string (if it
+        is not already) and delegates to :meth:`FsspecStacIO.write_text_from_href` for
+        opening and reading the file."""
+        href = str(os.fspath(dest))
+        return self.write_text_to_href(href, txt, **kwargs)
+
     def write_text_from_href(self, href: str, txt: str) -> None:
         utils.deprecate(
             "FsspecStacIO.write_text_from_href",
@@ -68,14 +94,15 @@ class FsspecStacIO(DefaultStacIO):
         )
         return self.write_text_to_href(href, txt)
 
-    def write_text_to_href(self, href: str, txt: str) -> None:
+    def write_text_to_href(self, href: str, txt: str, **kwargs: Any) -> None:
         """Writes text to an href using fsspec.
 
         Args:
             href (str): The href to write to.
             txt (str): The text to write.
+            **kwargs: Additional keyword arguments to be passed to fsspec.open.
         """
-        with fsspec.open(href, "w") as destination:
+        with fsspec.open(href, "w", **kwargs) as destination:
             destination.write(txt)
 
 
